@@ -15,7 +15,7 @@ def wtforms_translation_string_factory(domain):
     return _WTFormsLazyTranslationString
 
 
-def wtforms_translate_i18n_immediately(form):
+def wtforms_translate_i18n_now(form):
     '''
     When using wtforms_translation_string_factory with json renderer,
 
@@ -23,13 +23,13 @@ def wtforms_translate_i18n_immediately(form):
     from wtforms import FormField, FieldList
     for key, field in form._fields.items():
         if isinstance(field, FormField):
-            wtforms_translate_i18n_immediately(field)
+            wtforms_translate_i18n_now(field)
         elif isinstance(field, FieldList):
             for entry in field.entries:
-                _translate_field_immediately(entry)
+                _translate_field_now(entry)
         else:
-            _translate_field_immediately(field)
+            _translate_field_now(field)
 
-def _translate_field_immediately(field):
+def _translate_field_now(field):
     field.label.text = str(field.label.text)
     field.errors = [ str(i) for i in field.errors ]
